==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyGindexClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyGindexClass

// class file dependencies
// @dep_class 6754ad4c7b8f81e1 gnu_xml_xpath_XPathParser__24YyGindexClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyGindexClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyGindexClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct {
	_jc_short_array	*yyGindex;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods	gnu_xml_xpath_XPathParser__24YyGindexClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs	gnu_xml_xpath_XPathParser__24YyGindexClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyGindexClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyGindexClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyGindexClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyGindexClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyGindexClass

// class file dependencies
// @dep_class 6754ad4c7b8f81e1 gnu_xml_xpath_XPathParser__24YyGindexClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyGindexClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyGindexClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct {
	_jc_short_array	*yyGindex;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vmethods	gnu_xml_xpath_XPathParser__24YyGindexClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_refs	gnu_xml_xpath_XPathParser__24YyGindexClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyGindexClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyGindexClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyGindexClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyGindexClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyGindexClass_H_ */
